#[non_exhaustive]pub enum A2AError {
Http(String),
Parse(String),
Api {
code: i32,
message: String,
},
Timeout(String),
Signature(String),
InputRequired {
task_id: String,
prompt: String,
},
}Expand description
Errors that can occur during A2A client operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Http(String)
HTTP transport error.
Parse(String)
JSON parse error.
Api
API-level error (returned by the remote agent).
Timeout(String)
Request timed out.
Signature(String)
Agent card signature verification failed, or a signed card could not be verified (P1-3).
InputRequired
The agent needs more information before it can continue (P2-3).
Resume the conversation with A2AClient::resume_task.